@@ -15,11 +15,12 @@
 # limitations under the License.
 #
 
-from ai.h2o.sparkling.ml.params.H2OTargetEncoderMOJOParams import H2OTargetEncoderMOJOParams
 from pyspark.ml.util import JavaMLWritable
 from ai.h2o.sparkling.ml.util.H2OJavaMLReadable import H2OJavaMLReadable
 from pyspark.ml.wrapper import JavaModel
 
+from ai.h2o.sparkling.ml.params import H2OTargetEncoderParams
 
-class H2OTargetEncoderMOJOModel(H2OTargetEncoderMOJOParams, JavaModel, JavaMLWritable, H2OJavaMLReadable):
+
+class H2OTargetEncoderMOJOModel(H2OTargetEncoderParams, JavaModel, JavaMLWritable, H2OJavaMLReadable):
     pass
